@@ -134,8 +134,8 @@ For a full list of contributors, please check <a href="https://github.com/indili
 
 /* INDI Library version */
 #define INDI_VERSION_MAJOR   1
-#define INDI_VERSION_MINOR   8
-#define INDI_VERSION_RELEASE 7
+#define INDI_VERSION_MINOR   9
+#define INDI_VERSION_RELEASE 0
 
 /*******************************************************************************
  * Manifest constants
@@ -221,7 +221,7 @@ IP_RW  /*!< Read & Write */
  * @struct IText
  * @brief One text descriptor.
  */
-typedef struct
+typedef struct _IText
 {
 /** Index name */
 char name[MAXINDINAME];
@@ -271,7 +271,7 @@ typedef struct _ITextVectorProperty
  * @struct INumber
  * @brief One number descriptor.
  */
-typedef struct
+typedef struct _INumber
 {
     /** Index name */
     char name[MAXINDINAME];
@@ -344,7 +344,7 @@ typedef struct _INumberVectorProperty
  * @struct ISwitch
  * @brief One switch descriptor.
  */
-typedef struct
+typedef struct _ISwitch
 {
     /** Index name */
     char name[MAXINDINAME];
@@ -394,7 +394,7 @@ typedef struct _ISwitchVectorProperty
  * @struct ILight
  * @brief One light descriptor.
  */
-typedef struct
+typedef struct _ILight
 {
     /** Index name */
     char name[MAXINDINAME];
@@ -438,7 +438,7 @@ typedef struct _ILightVectorProperty
  * @struct IBLOB
  * @brief One Blob (Binary Large Object) descriptor.
  */
-typedef struct /* one BLOB descriptor */
+typedef struct _IBLOB/* one BLOB descriptor */
 {
     /** Index name */
     char name[MAXINDINAME];
